
:orphan:

Peter MacCallum Cancer Centre
=============================

Automatically generated index page for Peter MacCallum Cancer Centre:

.. raw:: html

   <ul>

   </ul>
     <a href="addbamstatsgermline.html">
       <p style="margin-bottom: 5px"><b>Annotate Bam Stats to Germline Vcf Workflow</b> <span style="margin-left: 10px; color: darkgray">AddBamStatsGermline</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(1 versions)</span><a class="version-button" href="addbamstatsgermline.html" style="margin-bottom: 10px">
       v<b>0.1.0</b>
     </a></p>
     </a>
     <hr />
         
     <a href="addbamstatssomatic.html">
       <p style="margin-bottom: 5px"><b>Annotate Bam Stats to Somatic Vcf Workflow</b> <span style="margin-left: 10px; color: darkgray">AddBamStatsSomatic</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(1 versions)</span><a class="version-button" href="addbamstatssomatic.html" style="margin-bottom: 10px">
       v<b>0.1.0</b>
     </a></p>
     </a>
     <hr />
         
     <a href="annotatedepthofcoverage.html">
       <p style="margin-bottom: 5px"><b>Annotate GATK3 DepthOfCoverage Workflow</b> <span style="margin-left: 10px; color: darkgray">AnnotateDepthOfCoverage</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(1 versions)</span><a class="version-button" href="annotatedepthofcoverage.html" style="margin-bottom: 10px">
       v<b>0.1.0</b>
     </a></p>
     </a>
     <hr />
         
     <a href="generategenomefileforbedtoolscoverage.html">
       <p style="margin-bottom: 5px"><b>Generate genome for BedtoolsCoverage</b> <span style="margin-left: 10px; color: darkgray">GenerateGenomeFileForBedtoolsCoverage</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(1 versions)</span><a class="version-button" href="generategenomefileforbedtoolscoverage.html" style="margin-bottom: 10px">
       v<b>0.1.0</b>
     </a></p>
     </a>
     <hr />
         
     <a href="generateintervalsbychromosome.html">
       <p style="margin-bottom: 5px"><b>Generating genomic intervals by chromosome</b> <span style="margin-left: 10px; color: darkgray">GenerateIntervalsByChromosome</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(1 versions)</span><a class="version-button" href="generateintervalsbychromosome.html" style="margin-bottom: 10px">
       v<b>0.1.0</b>
     </a></p>
     </a>
     <hr />
         
     <a href="generatevardictheaderlines.html">
       <p style="margin-bottom: 5px"><b>GenerateVardictHeaderLines</b> <span style="margin-left: 10px; color: darkgray">GenerateVardictHeaderLines</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(1 versions)</span><a class="version-button" href="generatevardictheaderlines.html" style="margin-bottom: 10px">
       v<b>0.1.0</b>
     </a></p>
     </a>
     <hr />
         
     <a href="molpathgermlineworkflow.html">
       <p style="margin-bottom: 5px"><b>Molpath Germline Workflow</b> <span style="margin-left: 10px; color: darkgray">MolpathGermlineWorkflow</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(1 versions)</span><a class="version-button" href="molpathgermlineworkflow.html" style="margin-bottom: 10px">
       v<b>1.0.0</b>
     </a></p>
     </a>
     <hr />
         
     <a href="molpathtumoronlyworkflow.html">
       <p style="margin-bottom: 5px"><b>Molpath Tumor Only Workflow</b> <span style="margin-left: 10px; color: darkgray">MolpathTumorOnlyWorkflow</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(1 versions)</span><a class="version-button" href="molpathtumoronlyworkflow.html" style="margin-bottom: 10px">
       v<b>1.0.0</b>
     </a></p>
     </a>
     <hr />
         
     <a href="parsefastqcadaptors.html">
       <p style="margin-bottom: 5px"><b>Parse FastQC Adaptors</b> <span style="margin-left: 10px; color: darkgray">ParseFastqcAdaptors</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(1 versions)</span><a class="version-button" href="parsefastqcadaptors.html" style="margin-bottom: 10px">
       v<b>0.1.0</b>
     </a></p>
     </a>
     <hr />
         
     <a href="performancesummarygenome.html">
       <p style="margin-bottom: 5px"><b>Performance summary workflow (whole genome)</b> <span style="margin-left: 10px; color: darkgray">PerformanceSummaryGenome</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(1 versions)</span><a class="version-button" href="performancesummarygenome.html" style="margin-bottom: 10px">
       v<b>0.1.0</b>
     </a></p>
     </a>
     <hr />
         
     <a href="performancesummarytargeted.html">
       <p style="margin-bottom: 5px"><b>Performance summary workflow (targeted bed)</b> <span style="margin-left: 10px; color: darkgray">PerformanceSummaryTargeted</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(1 versions)</span><a class="version-button" href="performancesummarytargeted.html" style="margin-bottom: 10px">
       v<b>0.1.0</b>
     </a></p>
     </a>
     <hr />
         
     <a href="splitmultiallele.html">
       <p style="margin-bottom: 5px"><b>Split Multiple Alleles</b> <span style="margin-left: 10px; color: darkgray">SplitMultiAllele</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(1 versions)</span><a class="version-button" href="splitmultiallele.html" style="margin-bottom: 10px">
       v<b>0.5772</b>
     </a></p>
     </a>
     <hr />
         
     <a href="splitmultiallelenormalisevcf.html">
       <p style="margin-bottom: 5px"><b>Split Multiple Alleles and Normalise Vcf</b> <span style="margin-left: 10px; color: darkgray">SplitMultiAlleleNormaliseVcf</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(1 versions)</span><a class="version-button" href="splitmultiallelenormalisevcf.html" style="margin-bottom: 10px">
       v<b>0.5772</b>
     </a></p>
     </a>
     <hr />
         
     <a href="addbamstats.html">
       <p style="margin-bottom: 5px"><b>Add Bam Statistics to Vcf</b> <span style="margin-left: 10px; color: darkgray">addBamStats</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(1 versions)</span><a class="version-button" href="addbamstats.html" style="margin-bottom: 10px">
       v<b>0.0.7</b>
     </a></p>
     </a>
     <hr />
         
     <a href="addsymtodepthofcoverage.html">
       <p style="margin-bottom: 5px"><b>Add Sym to DepthOfCoverage</b> <span style="margin-left: 10px; color: darkgray">addSymToDepthOfCoverage</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(1 versions)</span><a class="version-button" href="addsymtodepthofcoverage.html" style="margin-bottom: 10px">
       v<b>0.0.7</b>
     </a></p>
     </a>
     <hr />
         
     <a href="combinevariants.html">
       <p style="margin-bottom: 5px"><b>Combine Variants</b> <span style="margin-left: 10px; color: darkgray">combinevariants</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(1 versions)</span><a class="version-button" href="combinevariants.html" style="margin-bottom: 10px">
       v<b>0.0.8</b>
     </a></p>
     </a>
     <hr />
         
     <a href="extractstrelkasomaticaddp.html">
       <p style="margin-bottom: 5px"><b>Extract Strelka Somatic AD DP</b> <span style="margin-left: 10px; color: darkgray">extractStrelkaSomaticADDP</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(2 versions)</span><a class="version-button" href="extractstrelkasomaticaddp.html" style="margin-bottom: 10px">
       v<b>0.1.1</b>
     </a></p>
     </a>
     <hr />
         
     <a href="genecoveragepersample.html">
       <p style="margin-bottom: 5px"><b>Gene Coverage Per Sample</b> <span style="margin-left: 10px; color: darkgray">geneCoveragePerSample</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(2 versions)</span><a class="version-button" href="genecoveragepersample.html" style="margin-bottom: 10px">
       v<b>0.0.8</b>
     </a></p>
     </a>
     <hr />
         
     <a href="performancesummary.html">
       <p style="margin-bottom: 5px"><b>Performance Summary</b> <span style="margin-left: 10px; color: darkgray">performanceSummary</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(1 versions)</span><a class="version-button" href="performancesummary.html" style="margin-bottom: 10px">
       v<b>0.0.7</b>
     </a></p>
     </a>
     <hr />
         
     <a href="prepareallsortsinput.html">
       <p style="margin-bottom: 5px"><b>Prepare ALLSorts Input</b> <span style="margin-left: 10px; color: darkgray">prepareALLSortsInput</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(1 versions)</span><a class="version-button" href="prepareallsortsinput.html" style="margin-bottom: 10px">
       v<b>0.1.0</b>
     </a></p>
     </a>
     <hr />
         
     <a href="trimiupac.html">
       <p style="margin-bottom: 5px"><b>Trim IUPAC Bases</b> <span style="margin-left: 10px; color: darkgray">trimIUPAC</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(2 versions)</span><a class="version-button" href="trimiupac.html" style="margin-bottom: 10px">
       v<b>0.0.5</b>
     </a></p>
     </a>
     <hr />
         

